@@ -1,4 +1,4 @@
 from yfapi.yahoofinance import YahooFinance
-import exceptions
+import yfapi.exceptions
 
 __all__ = ['YahooFinance']
